import {select, json, geoPath, geoMercator, zoom, event, csv, scaleLinear, 
        schemeSpectral, scaleOrdinal} from 'd3';
import {feature} from 'topojson';
import {mapGenerator} from './mapGnerator';
import {colorLegend} from './colorLegend';
import {lineGraph} from'./lineGraph';

const year = 1970

const svg = select('svg');
const graphG = svg.append('g');
const g = svg.append('g');
const legendG = svg.append('g')
  .attr('transform', `translate(20,270)`);

const scaleLinearMap1 = scaleLinear();
const scaleLinearMap2 = scaleLinear();
const scaleOrdinalGraph = scaleOrdinal();

const colorValueMap1 = d => d.High_Value;
const colorValueMap2 = d => d.High_2018;
const xValue = d => d.Year;

const margin = { top: 60, right: 40, bottom: 88, left: 150 }

const width = +svg.attr('width');
const height = +svg.attr('height');

const innerWidth = width - margin.left - margin.right;
const innerHeight = height - margin.top - margin.bottom;

let stateGeoData;
let stateName;
let stateData;
let fullData;
let xMin = 10000000; //~longer than recorded history and way higher than the 2017 end of the dataset
let xMax = 0;
let yMin = 10000000; //bigger than any data record in the dataset
let yMax = 0;

const map1 = 'test'
const map2 = 'test2'

const onClick = (d, name) => {
  let index = selectedStates.mapName.indexOf(name);
  if (selectedStates.states[index].includes(d)) {
    let index2 = selectedStates.states[index].indexOf(d);
    selectedStates.states[index].splice(index2, 1);
  }
  else {
  selectedStates.states[index].push(d);
  }
  let allStates = []
  selectedStates.states.forEach(d => d.forEach(data => allStates.push(data)));
  selectedStates.uniqueStates = [...new Set(allStates)];
  selectedStates.nonRealStates = 0;
  selectedStates.uniqueStates.sort();
  let x = 57;
  while (selectedStates.uniqueStates.length < 3) {
    selectedStates.uniqueStates.push(x.toString());
    console.log(selectedStates.uniqueStates)
    x = x + 1;
    selectedStates.nonRealStates = selectedStates.nonRealStates + 1;
  }
  
  if (selectedStates.uniqueStates.length > 11) {
    selectedStates.uniqueStates = selectedStates.uniqueStates.splice(0, 11);
    }
  
  console.log(selectedStates)
  render()
}

let selectedStates ={
    mapName: [map1, map2],
    states: [[],[]],
    uniqueStates: ["57", "58", "59"],
    nonRealStates: 3};


const render = () => { 
    scaleLinearMap1
    .domain([0,Math.max.apply(null,stateData.map(colorValueMap1))])
    .range(['red', 'blue']);
  

  
  g.call(mapGenerator, {
    name: map1,
    scale: 0.4,
    yOffset: 0,
    xOffset: 0,
    fillColor: d=> {
      let name = (stateName[d.id.replace(/^[0]+/g,"") - 1].State);
      let row;
      stateData.forEach(d => {if(d.State === name) { row = d;}});
      
      return scaleLinearMap1(colorValueMap1(row)); 
    },
    strokeColor: 'black',
    selectedStates,
    stateGeoData,
    stateName,
    onClick
  })
  
  scaleLinearMap2
    .domain([0,Math.max.apply(null,stateData.map(colorValueMap2))])
    .range(['yellow', 'black']);
  
  
  g.call(mapGenerator, {
    name: map2,
    scale: 0.4,
    yOffset: 0,
    xOffset: 400,
    fillColor: d=> {
      let name = (stateName[d.id.replace(/^[0]+/g,"") - 1].State)
      let row;
      stateData.forEach(d => {if(d.State === name) { row = d;}})
      
      return scaleLinearMap2(colorValueMap2(row));
    },
    strokeColor: 'black',
    selectedStates,
    stateGeoData,
    stateName,
    onClick
  })
  
  
  scaleOrdinalGraph
    .domain(selectedStates.uniqueStates)
    .domain(scaleOrdinalGraph.domain().sort())
    .range(schemeSpectral[scaleOrdinalGraph.domain().length]);

  selectedStates.uniqueStates.splice(3-selectedStates.nonRealStates, selectedStates.nonRealStates);
  console.log(selectedStates)
  legendG.call(colorLegend, {
    colorScale:scaleOrdinalGraph,
    circleRadius: 8,
    spacing: 20,
    textOffset: 12,
    backgroundRectWidth: 0,
    stateName,
    selectedStates
  });
  
  graphG.call(lineGraph, {
    width,
    height,
    xValue,
    xAxisLabel: 'Year',
    colorValueMap1,
    colorValueMap2,
    selectedStates,
    circleRadius: 6,
    yAxisLabel: 'Minimum Wage $/hr',
    margin: {top: 250, right: 40, bottom: 88, left: 255},
    fullData,
    scaleOrdinalGraph,
    stateName,
    xMin,
    xMax,
    yMin,
    yMax
  });
  
};

//d.ID, d.State

Promise.all([csv('statesFix.csv'), 
             json('https://unpkg.com/us-atlas@1.0.2/us/10m.json'),
            csv('https://vizhub.com/zelekhut42/datasets/Minimum Wage Data With _.csv')])
  .then(([csv, json, state]) => {
    stateName = csv;
    stateGeoData = feature(json, json.objects.states);
  	state.forEach(d => {
      d.Year = +d.Year;
      if (d.High_Value === "NA") {
        d.High_Value = 0 
      } else {
      d.High_Value = +d.High_Value;
      }
      if (d.Low_Value === "NA") {
        d.Low_Value = 0
      } else {
      d.Low_Value = +d.Low_Value;
      }
      if (d.CPI_Average === "NA") {
        d.CPI_Average = 0
      } else {
      d.CPI_Average = +d.CPI_Average;
      }
      if (d.High_2018 === "NA") {
        d.High_2018 = 0
      } else {
      d.High_2018 = +d.High_2018;
      }
      if (d.Low_2018 === "NA") {
        d.Low_2018 = 0
      } else {
      d.Low_2018 = +d.Low_2018;
      }
      
      if (d.Year < xMin) {xMin = d.Year};
      
      if (d.Year > xMax) {xMax = d.Year};
      
      if (d.High_Value < yMin) {yMin = d.High_Value};
      
      if (d.High_Value > yMax) {yMax = d.High_Value};
      
      if (d.High_2018 < yMin) {yMin = d.High_2018};
      
      if (d.High_2018 > yMax) {yMax = d.High_2018};
    });
    fullData = state;
  	stateData = state.filter(function(d, i) {
        if (d["Year"] === year) {
      return d;
    }
    });
    render()
  });
  
