import {
  select,
  csv,
  scaleLinear,
  extent,
  axisLeft,
  axisBottom,
  line,
  curveBasis
} from 'd3';

export const lineGraph = (selection, props) => {
  const {
    width,
    height,
    xValue,
    xAxisLabel,
    colorValueMap1,
    colorValueMap2,
    selectedStates,
    circleRadius,
    yAxisLabel,
    margin,
    fullData,
    scaleOrdinalGraph,
    stateName,
    xMin,
    xMax,
    yMin,
    yMax
  } = props;
  
  //to do
  //doted/dashed line for map2


  let newData = [];

  selectedStates.states[0].forEach(d => {
    if (selectedStates.uniqueStates.includes(d)) {
      let name = stateName[parseInt(d) - 1].State;
      let objs = [];
      fullData.forEach(d => {if (d.State === name) {objs.push(d)}});
      newData.push({mapValue: selectedStates.mapName[0], objects: objs})
    }
  });

  selectedStates.states[1].forEach(d => {
    if (selectedStates.uniqueStates.includes(d)) {
      let name = stateName[parseInt(d) - 1].State;
      let objs = [];
      fullData.forEach(d => {if (d.State === name) {objs.push(d)}});
      newData.push({mapValue: selectedStates.mapName[1], objects: objs})
    }
  });

  const innerWidth = width - margin.left - margin.right;
  const innerHeight = height - margin.top - margin.bottom;

  const xScale = scaleLinear()
    .domain([xMin, xMax])
    .range([0, innerWidth])
    .nice();

  const yScale = scaleLinear()
    .domain([yMin, yMax])
    .range([innerHeight, 0])
    .nice();

  const xAxis = axisBottom(xScale)
    .tickSize(-innerHeight)
    .tickPadding(15);

  const yAxis = axisLeft(yScale)
    .tickSize(-innerWidth)
    .tickPadding(10);

  const gUpdate = selection.selectAll('.graphContainer').data([null]);
  const gEnter = gUpdate.enter().append('g').attr('class','graphContainer');
  const g = gEnter.merge(gUpdate)
  .attr('transform', `translate(${margin.left},${margin.top})`);

  const yAxisG = gUpdate.select('.yLabel');
  const yAxisGEnter = gEnter.append('g').attr('class', 'yLabel');

  yAxisG
    .merge(yAxisGEnter)
      .call(yAxis)
      .selectAll('.domain').remove();

  const yLabel = yAxisGEnter
    .append('text')
      .attr('class', 'axis-label')
      .attr('y', -60)
      .attr('fill', 'black')
      .attr('transform', `rotate(-90)`)
      .attr('text-anchor', 'middle')
    .merge(yAxisG.select('.axis-label'))
      .attr('x', -innerHeight / 2)
      .text(yAxisLabel);

  const xAxisG = gUpdate.select('.xLabel');
  const xAxisGEnter = gEnter.append('g').attr('class', 'xLabel');

  xAxisG
    .merge(xAxisGEnter)
      .call(xAxis)
      .attr('transform', `translate(0,${innerHeight})`)
      .selectAll('.domain').remove();


  const xLabel = xAxisGEnter
    .append('text')
      .attr('class', 'axis-label')
      .attr('y', 80)
      .attr('fill', 'black')
    .merge(xAxisG.select('.axis-label')) 
      .attr('x', innerWidth / 2)
      .text(xAxisLabel);
  

  const lineGeneratorMap1 = line()
    .x(d => xScale(xValue(d)))
    .y(d => yScale(colorValueMap1(d)))
    .curve(curveBasis);

  const lineGeneratorMap2 = line()
    .x(d => xScale(xValue(d)))
    .y(d => yScale(colorValueMap2(d)))
    .curve(curveBasis);

  //newData format [{mapValue:, objects:, ...}]

  const paths = g.selectAll('.line-pathtest,.line-pathtest2').data(newData);
  const pathsEnter = paths
    .enter().append('path')
      .attr('fill', 'none')
      .attr('stroke-width', 5);

  paths.merge(pathsEnter)
    .attr('class', d => 'line-path' + d.mapValue)
    .attr('d', d => d.mapValue === selectedStates.mapName[0]
         ? lineGeneratorMap1(d.objects)
         : lineGeneratorMap2(d.objects))
    .attr('stroke', d => {
      let name = d.objects[0].State
      let row;
      stateName.forEach(d => {if(d.State === name) { row = d;}})
      return scaleOrdinalGraph(row.ID)
  
  });
  
  paths.exit().remove();
}