import {select, json, geoPath, geoMercator, zoom, event} from 'd3';
import {feature} from 'topojson';

function scaler (scaleFactor, translation) {
        return d3.geoTransform({
            point: function(x, y) {
                this.stream.point(x * scaleFactor + translation[0], y  * scaleFactor + translation[1]);
            }
        });
    }


export const mapGenerator = (selection, props) => {
  const {
    name,
    scale,
    yOffset,
    xOffset,
    fillColor,
    strokeColor,
    selectedStates,
    stateGeoData,
    stateName,
    onClick
  } = props;
  
  

  var projection = geoMercator().fit

  const pathGenerator = geoPath().projection(scaler(scale, [xOffset, yOffset]));
  const paths = selection.selectAll('.' + name).data(stateGeoData.features)
  .enter().append('path')
  .attr('class', name)
  .attr('d', pathGenerator)
  .attr('fill', fillColor)
  .attr('stroke', strokeColor)
  .merge(selection.selectAll('.' + name))
  .on('click', d => onClick(d.id, name));

  
}